@@ -22,21 +22,10 @@ our @EXPORT = qw(cetak cetak_r cetak_pre);
 
 # Define Version :
 # ---------------------------------------------------------------- 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 # Create Subroutine for Get OS Server Information :
 # ------------------------------------------------------------------------
-=head1 SUBROUTINE os_server_info()
-
-    Description Subroutine :
-    ----------------------------------------
-    Subroutine yang berfungsi untuk menampilkan Informasi OS Server.
-
-    Parameter Subroutine :
-    ----------------------------------------
-    Tidak ada parameter Subroutine.
-
-=cut
 sub os_server_info {
     # ----------------------------------------------------------------
     # Prepare to get Operating System Information :
@@ -74,19 +63,6 @@ sub os_server_info {
 
 # Create Subroutine for get OS Client Information :
 # ------------------------------------------------------------------------
-=head1 SUBROUTINE os_client_info()
-
-    Deskripsi subroutine os_client_info() :
-    ----------------------------------------
-    Subroutine yang berfungsi untuk mendeteksi
-    nama sistem operasi yang digunakan melalui identifikasi
-    request HTTP.
-
-    Parameter Subroutine :
-    ----------------------------------------
-    No Argument or Parameter.
-
-=cut
 sub os_info {
     
     # Define self :
@@ -134,18 +110,6 @@ sub os_info {
 
 # Create Subroutine for Get Browser Information :
 # ------------------------------------------------------------------------
-=head1 SUBROUTINE browser_info()
-
-    Deskripsi subroutine browser_info() :
-    ----------------------------------------
-    Subroutine yang berfungsi untuk mendapatkan
-    informasi browser yang digunakan pada request HTTP.
-
-    Parameter Subroutine :
-    ----------------------------------------
-    No Parameter Subroutine.
-
-=cut
 sub browser_info {
     
     # Prepare to get Browser Information :
@@ -182,18 +146,6 @@ sub browser_info {
 
 # Create Subroutine for Delimiter Directory :
 # ------------------------------------------------------------------------
-=head1 SUBROUTINE delimiter_dir()
-
-    Description Subroutine :
-    ----------------------------------------
-    Subroutine yang berfungsi untuk deteksi Delimiter direktori
-    berdasarkan Sistem Operasi.
-
-    Parameter Subroutine :
-    ----------------------------------------
-    No Parameter Subroutine.
-
-=cut
 sub delimiter_dir {
     
     # Run Subroutine "os_server_info()" :
@@ -228,19 +180,7 @@ sub delimiter_dir {
 
 # Create Subroutine for get database config :
 # ------------------------------------------------------------------------
-=head1 SUBROUTINE get_dbconfig_php()
-
-    Deskripsi subroutine get_dbconfig() :
-    ----------------------------------------
-    Subroutine yang berfungsi untuk database config pada php.
-
-    Parameter Subroutine :
-    ----------------------------------------
-    $fileloc     =>  Nama file Database Config.
-    $dirloc      =>  Lokasi Direktori Database config.
-
-=cut
-sub get_dbconfig {
+sub get_dbconfig_php {
     
     # Define arguments subroutine :
     # ----------------------------------------------------------------
@@ -270,17 +210,6 @@ sub get_dbconfig {
 
 # Subroutine for get protocols :
 # ------------------------------------------------------------------------
-=head1 SUBROUTINE get_protocol()
-
-    Deskripsi subroutine get_protocol() :
-    ----------------------------------------
-    Subroutine yang berfungsi untuk mengambil data protocol.
-
-    Parameter subroutine get_protocol() :
-    ----------------------------------------
-    No parameter Subroutine.
-
-=cut
 sub get_protocol {
     
     # Prepare to get Protocol used :
@@ -302,17 +231,6 @@ sub get_protocol {
 
 # Subroutine for check IF module is exists :
 # ------------------------------------------------------------------------
-=head1 SUBROUTINE try_module()
-
-    Description Subroutine :
-    ----------------------------------------
-    Subroutine yang berfungsi untuk mengecek Module.
-
-    Parameter Subroutine :
-    ----------------------------------------
-    $module_name    => Berisi nama module, Ex: Your::module::name.
-
-=cut
 sub try_module {
     
     # Define parameter module :
@@ -341,24 +259,6 @@ sub try_module {
 
 # Subroutine for define time for Event MySQL :
 # ------------------------------------------------------------------------
-=head1 SUBROUTINE time_event_mysql()
-
-    Deskripsi subroutine time_event_mysql() :
-    ---------------------------------------------
-    Subroutine yang berfungsi untuk mendefinisikan Time Event MySQL.
-
-    Parameter subroutine time_event_mysql() :
-    ---------------------------------------------
-    $time_event         =>  Berisi Time Event.
-                            Ex: "1Y" => "tahun",
-                                "1M" => "bulan",
-                                "1W" => "minggu",
-                                "1D" => "Hari",
-                                "1H" => "Jam",
-                                "1m" => "menit",
-                                "1d" => "detik"
-
-=cut
 sub time_event_mysql {
     # ----------------------------------------------------------------
     # Define parameter Subroutine :
@@ -466,19 +366,6 @@ sub time_event_mysql {
 
 # Subroutine for Define format DATETIME MySQL :
 # ------------------------------------------------------------------------
-=head1 SUBROUTINE datetime_mysql()
-
-    Deskripsi subroutine datetime_mysql() :
-    ----------------------------------------
-    Subroutine yang berfungsi untuk mengkonversi "timestamp" ke
-    Format "DATETIME" MySQL.
-
-    Parameter subroutine datetime_mysql() :
-    ----------------------------------------
-    $timestamp          =>  Berisi Timestamp Format.
-    $timezone           =>  Berisi data Timezone. Ex: "Asia/Jakarta".
-
-=cut
 sub datetime_mysql {
     # ----------------------------------------------------------------
     # Define parameter subroutine :
@@ -514,21 +401,6 @@ sub datetime_mysql {
 
 # Subroutine for Print data with newline :
 # ------------------------------------------------------------------------
-=head1 SUBROUITNE cetak()
-
-    Deskripsi subroutine cetak() :
-    ----------------------------------------
-    Subroutine yang berfungsi untuk mencetak.
-
-    Parameter subroutine cetak() :
-    ----------------------------------------
-    $data           =>  berisi string yang akan di cetak.
-
-    Output Parameter :
-    ----------------------------------------
-    Hasil cetakan.
-
-=cut
 sub cetak {
 	# ----------------------------------------------------------------
 	# Define parameter subroutine :
@@ -544,21 +416,6 @@ sub cetak {
 
 # Subroutine for Print ref :
 # ------------------------------------------------------------------------
-=head1 SUBROUTINE cetak_r()
-
-    Deskripsi subroutine cetak_r() :
-    ----------------------------------------
-    Subroutine yang berfungsi untuk mencetak referensi dengan Data::Dumper atau "Dumper"
-
-    Parameter subroutine cetak_r() :
-    ----------------------------------------
-    Parameter bisa scalar, array, hash atau referensi.
-
-    Output Parameter :
-    ----------------------------------------
-    Print Referensi.
-
-=cut
 sub cetak_r {
     # ----------------------------------------------------------------
     # Check Parameter Subroutine :
@@ -581,22 +438,6 @@ sub cetak_r {
 
 # Subroutine for print ref with pre tag HTML :
 # ------------------------------------------------------------------------
-=head1 SUBROUTINE cetak_pre()
-
-    Deskripsi subroutine cetak_pre() :
-    ----------------------------------------
-    Subroutine yang berfungsi untuk mencetak dengan Data::Dumper atau "Dumper"
-    beserta tag "<pre>" html.
-
-    Parameter subroutine cetak_pre() :
-    ----------------------------------------
-    Parameter bisa scalar, array, hash atau referensi.
-
-    Output Parameter :
-    ----------------------------------------
-    Print Referensi.
-
-=cut
 sub cetak_pre {
     # ----------------------------------------------------------------
     # Check Parameter Subroutine :
@@ -618,26 +459,6 @@ sub cetak_pre {
 }
 # End of Subroutine for print ref with pre tag HTML
 # ===========================================================================================================
-
-
 1;
 __END__
-=head1 NAME
-
-NKTI::general - The Part of NKTIweb The Simple Web Framework
-
-=head1 VERSION
-
-This document describes NKTI::general version 0.11.
-
-=head2 AUTHOR
-
-Achmad Yusri Afandi, (linuxer08@gmail.com).
-
-=head2 COPYRIGHT AND LICENSE
-
-Copyright (c) 2016, Achmad Yusri Afandi, All Rights reserved.
-
-Pustaka yang berfungsi untuk hal-hal umum dalam web aplikasi.
-
-=cut
\ No newline at end of file
+#
\ No newline at end of file
