@@ -5,18 +5,10 @@ use warnings;
 
 # Define Version
 # ----------------------------------------------------------------
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 # Create Action Split Character in string :
 # ------------------------------------------------------------------------
-=head1 MODULE base_length()
-
-    Parameter Modul :
-    ----------------------------------------
-    _string =>    Parameter yang berisi string yang akan di split.
-    _length =>    Parameter yang berisi jumlah.
-
-=cut
 sub based_length {
 
     # Declare parameter module :
@@ -39,16 +31,6 @@ sub based_length {
 
 # Create Module Split Charcter by Character :
 # ------------------------------------------------------------------------
-=head1 MODULE based_char()
-
-    Parameter Modul :
-    ----------------------------------------
-    _string =>      Parameter yang berisi string untuk yang akna displit.
-    _delimiter =>   Parameter yang berisi karakter pemisa untuk proses split karakter.
-    _join =>        Parameter yang berisi nilai aksi join.
-                    IF == 1 --> Split direct join,
-                    IF == 0 --> Split return array.
-=cut
 sub based_char {
 
     # Declara parameter module :
@@ -108,16 +90,6 @@ sub based_char {
 }
 # End of Create Module Split Charcter by Character.
 # ===========================================================================================================
-
 1;
-
 __END__
-=head1 AUTHOR
-    Achmad Yusri Afandi, (linuxer08@gmail.com)
-
-=head1 COPYRIGHT AND LICENSE
-    Copyright (c) 2016, Achmad Yusri Afandi, All Rights reserved.
-
-    Pustaka yang berfungsi untuk melakukan Split Karakter.
-
-=cut
\ No newline at end of file
+#
\ No newline at end of file
